Name:           lightdm
Version:        0.4.2
Release:        1%{?dist}
Summary:        Lightweight Display Manager

Group:          User Interface/X
License:        GPLv2+
URL:            http://www.freedesktop.org/wiki/Software/LightDM
Source0:        http://launchpad.net/lightdm/trunk/%{version}/+download/lightdm-%{version}.tar.gz
Source1:        lightdm.pam
Patch1:         lightdm-0.4.0-themes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  ConsoleKit-devel
BuildRequires:  dbus-glib-devel
BuildRequires:  gtk-doc
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  pam-devel
BuildRequires:  qt-devel
BuildRequires:  vala
%if 0%{?fedora} >= 15
BuildRequires:  gobject-introspection-devel >= 0.9.5
%endif
Requires:       pam
Requires:       /sbin/shutdown
Requires:       desktop-backgrounds-compat
Requires:       dbus-x11
Requires:       %{name}-greeter
Requires(pre):  /usr/sbin/adduser
# needed for anaconda to boot into runlevel 5 after install
Provides:       service(graphical-login) = lightdm

%description
LightDM is an X display manager that:
* Has a lightweight codebase
* Is standards compliant (PAM, ConsoleKit, etc)
* Has a well defined interface between the server and user interface
* Fully themeable (easiest with the webkit interface)
* Cross-desktop (greeters can be written in any toolkit)


%package        gtk
Summary:        LightDM GTK+ Greeter Engine
Group:          User Interface/X
Requires:       %{name} = %{version}-%{release}
Requires:       desktop-backgrounds-compat
Provides:       %{name}-greeter

%description    gtk
This package contains a LightDM greeter engine that runs themes that use the 
GTK+ toolkit.


%package        python-gtk
Summary:        LightDM GTK+ Greeter Engine
Group:          User Interface/X
Requires:       %{name} = %{version}-%{release}
Requires:       desktop-backgrounds-compat
Provides:       %{name}-greeter

%description    python-gtk
This package contains a LightDM greeter engine that runs themes that use the 
GTK+ toolkit.


#%package        webkit
#Summary:        LightDM GTK WebKit Greeter Engine
#Group:          User Interface/X
#Requires:       %{name} = %{epoch}:%{version}-%{release}
#Provides:       %{name}-greeter
#
#%description    webkit
#This package contains a LightDM greeter engine that runs greeter themes that are
#written in HTML/CSS/Javascript.


#%package        gobject
#Summary:        LightDM GObject client library
#Group:          User Interface/X
#Requires:       %{name} = %{version}-%{release}

#%description    gobject
#This package contains a GObject based library for LightDM clients to use to 
#interface with LightDM.


%package        qt
Summary:        LightDM QT client library
Group:          User Interface/X
Requires:       %{name} = %{version}-%{release}

%description    qt
This package contains a QT based library for LightDM clients to use to interface
with LightDM.


%package        vala
Summary:        LightDM Vala Greeter Engine
Group:          User Interface/X
Requires:       %{name} = %{version}-%{release}
Requires:       desktop-backgrounds-compat
Provides:       %{name}-greeter

%description    vala
This package contains a LightDM greeter engine that runs themes that use the 
Vala toolkit.


%package        devel
Summary:        Development files for LightDM
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains libraries, header files and documentation for developing 
greeters for LightDM.


%prep
%setup -q
%patch1 -p1 -b .themes

# uic is called uic-qt4 in our distribution
sed -i 's/uic/uic-qt4/' greeters/qt/Makefile.*

# AUTHORS is empty, let's fix this
echo "Robert Ancell <robert.ancell@canonical.com>" > AUTHORS


%build
%configure --disable-static \
    --enable-gtk-doc \
    --enable-liblightdm-qt \
    %if 0%{?fedora} >= 15
    --enable-introspection \
    %endif
    --with-greeter-user=lightdm \
    --with-greeter-theme-dir=%{_datadir}/lightdm/themes
#    --with-default-xsession=gnome \
#    --with-theme=example-gtk-gnome \

# kill rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# The LD_LIBRARY_PATH hack is needed for --enable-gtk-doc because 
# lt-lightdm-gobject-0-scan is linked against liblightdm-gobject-0.so.0
export LD_LIBRARY_PATH=$( pwd )/liblightdm-gobject/.libs

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT INSTALL='install -p'
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

# install pam file
install -Dpm 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/lightdm

# We need to own these
#mkdir -p %{buildroot}%{_localstatedir}/cache/%{name}/{authority,dmrc}
mkdir -p %{buildroot}%{_localstatedir}/run/%{name}/authority
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}

# replace background images
rm -f %{buildroot}{_datadir}/lightdm/themes/*/bg.jpg
for theme in %{buildroot}%{_datadir}/lightdm/themes/example-*gnome ; do
    ln -s ../../../backgrounds/default.png $theme/bg.png
done


%clean
rm -rf $RPM_BUILD_ROOT


#%pre
#/usr/sbin/useradd -M -u 43 -d /var/log/lightdm -s /sbin/nologin -r lightdm > /dev/null 2>&1
#/usr/sbin/usermod -d /var/log/gdm -s /sbin/nologin lightdm >/dev/null 2>&1
# ignore errors, as we can't disambiguate between lightdm already existed
# and couldn't create account with the current adduser.
#exit 0

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.DisplayManager.conf
%config(noreplace) %{_sysconfdir}/init/lightdm.conf
#%config(noreplace) %{_sysconfdir}/pam.d/lightdm
%dir %{_sysconfdir}/lightdm/
%config(noreplace) %{_sysconfdir}/lightdm/lightdm.conf
%{_bindir}/lightdm
%{_libdir}/liblightdm-gobject-0.so.*
%{_libdir}/girepository-1.0/LightDM-0.typelib
%{_mandir}/man*/lightdm.*.*
%dir %{_datadir}/lightdm/
%dir %{_datadir}/lightdm/themes/
#%dir %attr(1755,root,lightdm) %{_localstatedir}/cache/%{name}/
%dir %attr(1755,root,lightdm)%{_localstatedir}/run/%{name}/authority
%dir %attr(1750,root,lightdm) %{_localstatedir}/log/%{name}/


%files gtk
%{_libexecdir}/lightdm-example-gtk-greeter
%{_datadir}/lightdm/themes/example-gtk-gnome/
%{_datadir}/lightdm-example-gtk-greeter/


%files python-gtk
%{_libexecdir}/lightdm-example-python-gtk-greeter
%{_datadir}/lightdm/themes/example-python-gtk-gnome/


#%files webkit
#%{_libexecdir}/ldm-webkit-greeter
#%{_datadir}/lightdm/themes/webkit/


#%files gobject
#%{_libdir}/liblightdm-gobject-0.so.*


%files qt
%{_libdir}/liblightdm-qt-0.so.*
%{_libexecdir}/lightdm-example-qt-greeter
%{_datadir}/lightdm/themes/example-qt-kde/


%files vala
%{_libexecdir}/lightdm-example-vala-gtk-greeter
%{_datadir}/lightdm/themes/example-vala-gtk-gnome/


%files devel
%defattr(-,root,root,-)
%doc %{_datadir}/gtk-doc/html/lightdm-gobject-0/
%{_includedir}/lightdm-gobject-0/
%{_includedir}/lightdm-qt-0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/liblightdm-gobject-0.pc
%{_libdir}/pkgconfig/liblightdm-qt-0.pc
%{_datadir}/gir-1.0/LightDM-0.gir
%{_datadir}/vala/vapi/liblightdm-gobject-0.vapi


%changelog
* Fri Jul 08 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.4.2-1
- Update to 0.4.2

* Sat Jul 02 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.4.1-1
- Update to 0.4.1

* Sat Jun 25 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.4.0-1
- Update to 0.4.0

* Fri Apr 22 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.2-1
- Update to 0.3.2

* Sun Jan 23 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.2.3-1
- Update to 0.2.3

* Sat Oct 23 2010 Christoph Wickert <cwickert@fedoraproject.org> - 0.1.2-1
- Initial package
